@@ -339,9 +339,21 @@ class Renderer(JsRenderer, JsCacheRenderer):
                           )
 
             # if v.action.show_in_bbar: result["bbar"] = True # not needed
-            if v.action.window_type: result["toolbarActions"] = [ba.action.action_name for ba in
-                                                                 v.actor.get_toolbar_actions(
-                                                                     v.action)]
+            if v.action.window_type:
+                tba = []
+                combo_group = None
+                for ba in v.actor.get_toolbar_actions(v.action):
+                    if ba.action.combo_group == combo_group and combo_group is not None:
+                        previous = tba.pop()
+                        if not isinstance(previous, list):
+                            previous = [previous]
+                        previous.append(ba.action.action_name)
+                        tba.append(previous)
+                    else: # is normal
+                        tba.append(ba.action.action_name)
+                        combo_group = ba.action.combo_group
+                result["toolbarActions"] = tba
+
 
             return result
         if isclass(v) and issubclass(v, Actor):
@@ -370,7 +382,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                       "use_detail_param_panel "  # show PV panel in detail
                                       "use_detail_params_value "  # in grid, use parrent PV values
                                       "hide_top_toolbar "  # No selection and toolbar
-                                      "use_detail_params_value "))
+                                      "use_detail_params_value "
+                                      "react_responsive " 
+                                      "react_big_search "))
             # mt + slave-tables
 
             chooser_dict = getattr(v.model, "_choosers_dict", {})
